import { EventEmitter } from 'eventemitter3';
import Redis from 'ioredis';
import { RedisScriptCall } from './redis-utils';
export declare type HandleConsumedMessageCall = (messageData: any, lock: LockHandle) => Promise<void>;
export interface LockHandle {
    groupId: string;
    messageId: string;
    queueId: string;
    consumerId: string;
}
export interface ConstructorArgs {
    redis: Redis.Redis;
    batchSize: number;
    groupVisibilityTimeoutMs: number;
    pollingTimeoutMs: number;
    handleMessage: HandleConsumedMessageCall;
    groupStreamKey: string;
    groupSetKey: string;
    clientIndexKey: string;
    consumerGroupId: string;
    callClaimTimedOutGroup: RedisScriptCall;
    callUnlockGroup: RedisScriptCall;
    callDeleteMessage: RedisScriptCall;
    createPriorityMessageQueueKey: (groupId: string) => string;
}
export interface Events {
    stopped(): void;
}
export declare class RedisQueueWorker extends EventEmitter<Events> {
    private parentRedis;
    private redis;
    private batchSize;
    private groupVisibilityTimeoutMs;
    private pollingTimeoutMs;
    private handleMessage;
    private groupStreamKey;
    private groupSetKey;
    private clientIndexKey;
    private consumerGroupId;
    private _createPriorityMessageQueueKey;
    private consumerId;
    private callClaimTimedOutGroup;
    private callUnlockGroup;
    private callDeleteMessage;
    private isRunning;
    constructor({ redis, batchSize, groupVisibilityTimeoutMs, pollingTimeoutMs, handleMessage, groupStreamKey, groupSetKey, clientIndexKey, consumerGroupId, callClaimTimedOutGroup, callUnlockGroup, callDeleteMessage, createPriorityMessageQueueKey }: ConstructorArgs);
    start(): Promise<void>;
    stop(): Promise<void>;
    private _poll;
    private _process;
    private _lock;
    private _claim_timed_out_lock;
    private _unlock;
    private _peek;
    private _delete;
}
